==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/General/rgscan/translations/rgscan_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>RGScanDialog</name>
    <message>
        <location filename="../rgscandialog.ui" line="14"/>
        <source>ReplayGain Scanner</source>
        <translation>Skaner ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="84"/>
        <source>Write track gain/peak</source>
        <translation>Zapisz wzmocnienie/szczyt utworu</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="42"/>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="47"/>
        <source>Progress</source>
        <translation>Postęp</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="52"/>
        <source>Track Gain</source>
        <translation>Wzmocnienie utworu</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="57"/>
        <source>Album Gain</source>
        <translation>Wzmocnienie albumu</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="62"/>
        <source>Track Peak</source>
        <translation>Szczyt utworu</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="67"/>
        <source>Album Peak</source>
        <translation>Szczyt albumu</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="77"/>
        <source>Skip already scanned files</source>
        <translation>Pomiń już zeskanowane pliki</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="113"/>
        <source>Calculate</source>
        <translation>Oblicz</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="120"/>
        <source>Write Tags</source>
        <translation>Zapisz tagi</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="91"/>
        <source>Write album gain/peak</source>
        <translation>Zapisz wzmocnienie/szczyt albumu</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="130"/>
        <location filename="../rgscandialog.cpp" line="241"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="140"/>
        <location filename="../rgscandialog.cpp" line="141"/>
        <location filename="../rgscandialog.cpp" line="165"/>
        <location filename="../rgscandialog.cpp" line="236"/>
        <source>%1 dB</source>
        <translation>%1 dB</translation>
    </message>
</context>
<context>
    <name>RGScanFactory</name>
    <message>
        <location filename="../rgscanfactory.cpp" line="29"/>
        <source>ReplayGain Scanner Plugin</source>
        <translation>Wtyczka Skaner ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="50"/>
        <source>About ReplayGain Scanner Plugin</source>
        <translation>O wtyczce Skaner ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="51"/>
        <source>ReplayGain Scanner Plugin for Qmmp</source>
        <translation>Wtyczka Skaner ReplayGain dla Qmmp</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="52"/>
        <source>This plugin scans audio files and gives information for volume normalization</source>
        <translation>Wtyczka skanuje pliki dźwiękowe i podaje informacje na temat normalizacji dźwięku</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Napisana przez: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="54"/>
        <source>Based on source code by:</source>
        <translation>Oparta na kodzie stworzonym przez:</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="55"/>
        <source>David Robinson &lt;David@Robinson.org&gt;</source>
        <translation>David Robinson &lt;David@Robinson.org&gt;</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="56"/>
        <source>Glen Sawyer &lt;mp3gain@hotmail.com&gt;</source>
        <translation>Glen Sawyer &lt;mp3gain@hotmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="57"/>
        <source>Frank Klemm</source>
        <translation>Frank Klemm</translation>
    </message>
</context>
<context>
    <name>RGScanHelper</name>
    <message>
        <location filename="../rgscanhelper.cpp" line="32"/>
        <source>ReplayGain Scanner</source>
        <translation>Skaner ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanhelper.cpp" line="33"/>
        <source>Meta+R</source>
        <translation>Meta+R</translation>
    </message>
</context>
</TS>

==> qmmp-1.0.7.tar.bz2: qmmp-1.0.7/src/plugins/General/rgscan/translations/rgscan_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>RGScanDialog</name>
    <message>
        <location filename="../rgscandialog.ui" line="14"/>
        <source>ReplayGain Scanner</source>
        <translation>Skaner ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="84"/>
        <source>Write track gain/peak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="42"/>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="47"/>
        <source>Progress</source>
        <translation>Postęp</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="52"/>
        <source>Track Gain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="57"/>
        <source>Album Gain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="62"/>
        <source>Track Peak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="67"/>
        <source>Album Peak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="77"/>
        <source>Skip already scanned files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="113"/>
        <source>Calculate</source>
        <translation>Oblicz</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="120"/>
        <source>Write Tags</source>
        <translation>Zapisz Tagi</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="91"/>
        <source>Write album gain/peak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="117"/>
        <location filename="../rgscandialog.cpp" line="228"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="127"/>
        <location filename="../rgscandialog.cpp" line="128"/>
        <location filename="../rgscandialog.cpp" line="152"/>
        <location filename="../rgscandialog.cpp" line="223"/>
        <source>%1 dB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RGScanFactory</name>
    <message>
        <location filename="../rgscanfactory.cpp" line="29"/>
        <source>ReplayGain Scanner Plugin</source>
        <translation>Wtyczka Skaner ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="50"/>
        <source>About ReplayGain Scanner Plugin</source>
        <translation>O wtyczce Skaner ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="51"/>
        <source>ReplayGain Scanner Plugin for Qmmp</source>
        <translation>Wtyczka ReplayGain dla Qmmp</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="52"/>
        <source>This plugin scans audio files and gives information for volume normalization</source>
        <translation>Wtyczka skanuje pliki dźwiękowe i podaje informacje na temat normalizacji dźwięku</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="54"/>
        <source>Based on source code by:</source>
        <translation>Oparte na kodzie stworzonym przez:</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="55"/>
        <source>David Robinson &lt;David@Robinson.org&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="56"/>
        <source>Glen Sawyer &lt;mp3gain@hotmail.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="57"/>
        <source>Frank Klemm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RGScanHelper</name>
    <message>
        <location filename="../rgscanhelper.cpp" line="32"/>
        <source>ReplayGain Scanner</source>
        <translation>Skaner ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanhelper.cpp" line="33"/>
        <source>Meta+R</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
